@@ -7,6 +7,7 @@ import subprocess
 import time
 
 from tronpytool import Tron
+from tronpytool.trx import Trx
 
 ROOT = os.path.join(os.path.dirname(__file__))
 
@@ -88,31 +89,32 @@ class CoreDeploy:
     with the right strategies
     """
     _contract_dict: dict
-    FILE_CONTRACT = "backedup"
+    SUB_FIX = ""
     ACTION_FOLDER = "deploy_results"
-    COLLECTION_CONTRACTS = "deployments"
+    FILE_NAME = "deploy_{}{}.json"
 
     def __init__(self, tron: Tron):
         self.tron = tron
+        self.last_class = ""
         self._contract_dict = dict()
 
     @property
-    def backupname(self) -> str:
+    def subFix(self) -> str:
         """preview the file name"""
-        return self.FILE_CONTRACT
+        return self.SUB_FIX
 
-    @backupname.setter
-    def backupname(self, filename: str) -> None:
+    @subFix.setter
+    def subFix(self, sub: str) -> None:
         """the file name does not require extension name"""
-        self.FILE_CONTRACT = filename
+        self.SUB_FIX = sub
 
     @property
-    def deployment_location(self) -> str:
-        return self.COLLECTION_CONTRACTS
+    def deployed_record(self) -> str:
+        return self.FILE_NAME.format(self.tron.network_name, self.SUB_FIX)
 
-    @deployment_location.setter
-    def deployment_location(self, path: str) -> None:
-        self.COLLECTION_CONTRACTS = path
+    @property
+    def deployedAddrsFilePath(self) -> str:
+        return os.path.join(self.sol_cont.workspace, self.ACTION_FOLDER, self.deployed_record)
 
     def getAddr(self, keyname: str) -> str:
         """example: TT67rPNwgmpeimvHUMVzFfKsjL9GZ1wGw8"""
@@ -136,10 +138,6 @@ class CoreDeploy:
     def preview_all_addresses(self) -> None:
         print(self._contract_dict)
 
-    def deployedAddrsFilePath(self) -> str:
-        return os.path.join(self.sol_cont.workspace, self.ACTION_FOLDER,
-                            "{}.json".format(self.COLLECTION_CONTRACTS))
-
     def is_deployment(self) -> bool:
         return self.is_deploy
 
@@ -154,7 +152,7 @@ class CoreDeploy:
         if not deploy:
             """try to load up the file from the existing path"""
             try:
-                self._contract_dict = json.load(codecs.open(self.deployedAddrsFilePath(), 'r', 'utf-8-sig'))
+                self._contract_dict = json.load(codecs.open(self.deployedAddrsFilePath, 'r', 'utf-8-sig'))
                 print("==== 🛄 data is prepared and it is ready now.. ")
                 self.preview_all_addresses()
             except ValueError:
@@ -164,7 +162,7 @@ class CoreDeploy:
 
     def complete_deployment(self) -> None:
         """store up the deployed contrcat addresses to the local file storage"""
-        self.sol_cont.StoreTxResult(self._contract_dict, self.deployedAddrsFilePath())
+        self.sol_cont.StoreTxResult(self._contract_dict, self.deployedAddrsFilePath)
 
     def deploy(self, sol_wrap: SolcWrap, classname: str, params: list = []) -> str:
         """This is using the faster way to deploy files by using the specific abi and bin files"""
@@ -185,9 +183,27 @@ class CoreDeploy:
         sol_wrap.StoreTxResult(result, path)
         contract_address = self.tron.address.from_hex(result["transaction"]["contract_address"])
         self._contract_dict[classname] = contract_address
+        self._contract_dict["kv_{}".format(classname)] = dict(
+            uid=0,
+            canvagas=False
+        )
         print("======== address saved to ✅ {} -> {}".format(contract_address, classname))
         return contract_address
 
+    def setTargetClass(self, classname: str) -> "CoreDeploy":
+        self.last_class = classname
+        return self
+
+    def setKV(self, key: str, value: any) -> "CoreDeploy":
+        self._contract_dict["kv_{}".format(self.last_class)][key] = value
+        return self
+
+    def getVal(self, key: str) -> any:
+        return self._contract_dict["kv_{}".format(self.last_class)][key]
+
+    def SaveConfig(self) -> None:
+        self.complete_deployment()
+
     def classic_deploy(self, sol_wrap: SolcWrap, path: str, classname: str, params: list = []) -> str:
         self.sol_cont.WrapModel()
         _abi, _bytecode = sol_wrap.GetCode(path, classname)
@@ -225,10 +241,21 @@ class WrapContract(object):
 
         self._tron_module = nn1.trx
         self._contract = None
+        self._network = _network
 
     def getClientTron(self) -> "Tron":
         return self.tron_client
 
+    def getTrxModule(self) -> "Trx":
+        return self._tron_module
+
+    def getNewTronClient(self, wallet_address: str, pri_key: str) -> "Tron":
+        client = Tron().setNetwork(self._network)
+        client.private_key = pri_key
+        client.default_address = wallet_address
+
+        return client
+
     def setMasterKey(self, pub: str, pri: str) -> "WrapContract":
         self.tron_client.private_key = pri
         self.tron_client.default_address = pub
