@@ -35,24 +35,24 @@ from trx_utils import (
 )
 
 from tronpytool import constants
-from tronpytool.common.abi import map_abi_data
-from tronpytool.common.account import Address, PrivateKey, Account
-from tronpytool.common.encoding import (
+from .common.abi import map_abi_data
+from .common.account import Address, PrivateKey, Account
+from .common.encoding import (
     to_bytes,
     to_int,
     to_text,
     to_json,
     hex_encode_abi_type
 )
-from tronpytool.common.key import PrivateKey as PrivateKeyFactory
-from tronpytool.common.normalizers import abi_resolver
-from tronpytool.exceptions import (
+from .common.key import PrivateKey as PrivateKeyFactory
+from .common.normalizers import abi_resolver
+from .exceptions import (
     InvalidTronError,
     TronError
 )
-from tronpytool.manager import TronManager
-from tronpytool.transactionbuilder import TransactionBuilder
-from tronpytool.trx import Trx
+from .manager import TronManager
+from .transactionbuilder import TransactionBuilder
+from .trx import Trx
 
 DEFAULT_MODULES = {
     'trx': Trx
@@ -120,14 +120,19 @@ class Tron:
         modules = kwargs.setdefault('modules', DEFAULT_MODULES)
         for module_name, module_class in modules.items():
             module_class.attach(self, module_name)
-
+        self._network = ""
         self.transaction_builder = TransactionBuilder(self)
 
-    def setNetwork(self, networkname="nile"):
+    def setNetwork(self, networkname: str = "nile") -> "Tron":
         group = constants.conf_for_name(networkname)
         self.manager = TronManager(self, constants.to_providers_set(group))
+        self._network = networkname
         return self
 
+    @property
+    def network_name(self) -> str:
+        return self._network
+
     @property
     def default_block(self):
         return self._default_block
@@ -157,7 +162,6 @@ class Tron:
     def getKey(self) -> "PrivateKey":
         return self.private_key_class
 
-
     @private_key.setter
     def private_key(self, value: str) -> None:
         """Set a private key used with the TronAPI instance,
